| Rplus | R Documentation |
Rplus(Seed, NVar = NULL, rdist = NULL, param1 = NULL, param2 = NULL, s = NULL)
Rplus(Seed, NVar = NULL, rdist = NULL, param1 = NULL, param2 = NULL, s = NULL)
Seed |
(scalar) A seed for the random number generator. If
|
NVar |
(integer) The order of the generated correlation (R) matrix. |
rdist |
(character) A one or two letter character string that determines the distribution for the elements of the Cholesky factor of the randomly generated covariance matrix. Possible values include
|
param1 |
(scalar). The first parameter of rdist. |
param2 |
(scalar). The second parameter of rdist |
s |
(scalar). An optional scalar |
R The generated R matrix.
NVar The order of R.
rdist The user-supplied character strong for rdist,
param1 The first parameter of rdist.
param2 The possible second parameter of rdist.
s The user-supplied scaling factor.
Seed the starting value for the random number generator.
Niels G. Waller
# --- Example 1: Generate two random R with positive rij ----
R = Rplus(Seed = 123,
NVar = 6,
rdist = "F",
param1 = 2.5,
param2 = 25,
s = .8)$R
R |> round(2)
R = Rplus(Seed = 456,
NVar = 6,
rdist = "F",
param1 = 2.5,
param2 = 25,
s = .8)$R
R |> round(2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.